@@ -9,7 +9,6 @@ def home(request):
     """
     home page
     """
-
     return render_to_response('home.html')
 
 
@@ -17,13 +16,16 @@ def demo_piechart(request):
     """
     pieChart page
     """
-    xdata = ["Orange", "Banana", "Pear", "Kiwi", "Apple", "Strawberry", "Pineapple"]
-    ydata = [3, 4, 0, 1, 5, 7, 3]
-    chartdata = {'x': xdata, 'y': ydata}
+    xdata = ["Apple", "Apricot", "Avocado", "Banana", "Boysenberries", "Blueberries", "Dates", "Grapefruit", "Kiwi", "Lemon"]
+    ydata = [52, 48, 160, 94, 75, 71, 490, 82, 46, 17]
+
+    extra_serie = {"tooltip": {"y_start": "", "y_end": " cal"}}
+    chartdata = {'x': xdata, 'y1': ydata, 'extra1': extra_serie}
     charttype = "pieChart"
+
     data = {
         'charttype': charttype,
-        'chartdata': chartdata
+        'chartdata': chartdata,
     }
     return render_to_response('piechart.html', data)
 
@@ -39,7 +41,10 @@ def demo_linechart(request):
     ydata = [i + random.randint(1, 10) for i in range(nb_element)]
     ydata2 = map(lambda x: x * 2, ydata)
 
-    chartdata = {'x': xdata, 'y1': ydata, 'y2': ydata2}
+    extra_serie = {"tooltip": {"y_start": "", "y_end": " cal"}}
+    chartdata = {'x': xdata,
+                 'name1': 'series 1', 'y1': ydata, 'extra1': extra_serie,
+                 'name2': 'series 2', 'y2': ydata2, 'extra2': extra_serie}
     charttype = "lineChart"
     data = {
         'charttype': charttype,
@@ -62,7 +67,15 @@ def demo_linewithfocuschart(request):
     ydata3 = map(lambda x: x * 3, ydata)
     ydata4 = map(lambda x: x * 4, ydata)
 
-    chartdata = {'x': xdata, 'y1': ydata, 'y2': ydata2, 'y3': ydata3, 'y4': ydata4}
+    extra_serie = {"tooltip": {"y_start": "There are ", "y_end": " calls"}}
+
+    chartdata = {
+        'x': xdata,
+        'name1': 'series 1', 'y1': ydata, 'extra1': extra_serie,
+        'name2': 'series 2', 'y2': ydata2, 'extra2': extra_serie,
+        'name3': 'series 3', 'y3': ydata3, 'extra3': extra_serie,
+        'name4': 'series 4', 'y4': ydata4, 'extra4': extra_serie
+    }
     charttype = "lineWithFocusChart"
     data = {
         'charttype': charttype,
@@ -82,7 +95,16 @@ def demo_multibarchart(request):
     ydata3 = map(lambda x: x * 3, ydata)
     ydata4 = map(lambda x: x * 4, ydata)
 
-    chartdata = {'x': xdata, 'y1': ydata, 'y2': ydata2, 'y3': ydata3, 'y4': ydata4}
+    extra_serie = {"tooltip": {"y_start": "There are ", "y_end": " calls"}}
+
+    chartdata = {
+        'x': xdata,
+        'name1': 'series 1', 'y1': ydata, 'extra1': extra_serie,
+        'name2': 'series 2', 'y2': ydata2, 'extra2': extra_serie,
+        'name3': 'series 3', 'y3': ydata3, 'extra3': extra_serie,
+        'name4': 'series 4', 'y4': ydata4, 'extra4': extra_serie
+    }
+
     charttype = "multiBarChart"
     data = {
         'charttype': charttype,
@@ -101,7 +123,14 @@ def demo_stackedareachart(request):
     ydata = [i + random.randint(1, 10) for i in range(nb_element)]
     ydata2 = map(lambda x: x * 2, ydata)
 
-    chartdata = {'x': xdata, 'y1': ydata, 'y2': ydata2}
+    extra_serie1 = {"tooltip": {"y_start": "", "y_end": " balls"}}
+    extra_serie2 = {"tooltip": {"y_start": "", "y_end": " calls"}}
+
+    chartdata = {
+        'x': xdata,
+        'name1': 'series 1', 'y1': ydata, 'extra1': extra_serie1,
+        'name2': 'series 2', 'y2': ydata2, 'extra2': extra_serie2,
+    }
     charttype = "stackedAreaChart"
     data = {
         'charttype': charttype,
@@ -119,7 +148,14 @@ def demo_multibarhorizontalchart(request):
     ydata = [i + random.randint(-10, 10) for i in range(nb_element)]
     ydata2 = map(lambda x: x * 2, ydata)
 
-    chartdata = {'x': xdata, 'y1': ydata, 'y2': ydata2}
+    extra_serie = {"tooltip": {"y_start": "", "y_end": " mins"}}
+
+    chartdata = {
+        'x': xdata,
+        'name1': 'series 1', 'y1': ydata, 'extra1': extra_serie,
+        'name2': 'series 2', 'y2': ydata2, 'extra2': extra_serie,
+    }
+
     charttype = "multiBarHorizontalChart"
     data = {
         'charttype': charttype,
@@ -141,7 +177,15 @@ def demo_lineplusbarchart(request):
     kwargs1 = {}
     kwargs1['bar'] = True
 
-    chartdata = {'x': xdata, 'y1': ydata, 'kwargs1': kwargs1, 'y2': ydata2}
+    extra_serie1 = {"tooltip": {"y_start": "$ ", "y_end": ""}}
+    extra_serie2 = {"tooltip": {"y_start": "", "y_end": " min"}}
+
+    chartdata = {
+        'x': xdata,
+        'name1': 'series 1', 'y1': ydata, 'extra1': extra_serie1, 'kwargs1': kwargs1,
+        'name2': 'series 2', 'y2': ydata2, 'extra2': extra_serie2,
+    }
+
     charttype = "linePlusBarChart"
     data = {
         'charttype': charttype,
@@ -161,7 +205,15 @@ def demo_cumulativelinechart(request):
     ydata = [i + random.randint(1, 10) for i in range(nb_element)]
     ydata2 = map(lambda x: x * 2, ydata)
 
-    chartdata = {'x': xdata, 'y1': ydata, 'y2': ydata2}
+    extra_serie1 = {"tooltip": {"y_start": "", "y_end": " calls"}}
+    extra_serie2 = {"tooltip": {"y_start": "", "y_end": " min"}}
+
+    chartdata = {
+        'x': xdata,
+        'name1': 'series 1', 'y1': ydata, 'extra1': extra_serie1,
+        'name2': 'series 2', 'y2': ydata2, 'extra2': extra_serie2,
+    }
+
     charttype = "cumulativeLineChart"
     data = {
         'charttype': charttype,
@@ -177,7 +229,10 @@ def demo_discretebarchart(request):
     xdata = ["A", "B", "C", "D", "E", "F", "G"]
     ydata = [3, 12, -10, 5, 35, -7, 2]
 
-    chartdata = {'x': xdata, 'y1': ydata}
+    extra_serie1 = {"tooltip": {"y_start": "", "y_end": " cal"}}
+    chartdata = {
+        'x': xdata, 'name1': '', 'y1': ydata, 'extra1': extra_serie1,
+    }
     charttype = "discreteBarChart"
     data = {
         'charttype': charttype,
@@ -200,13 +255,17 @@ def demo_scatterchart(request):
     kwargs2 = {'shape': 'cross'}
     kwargs3 = {'shape': 'triangle-up'}
 
-    chartdata = {'x': xdata,
-                 'y1': ydata1, 'kwargs1': kwargs1,
-                 'y2': ydata2, 'kwargs2': kwargs2,
-                 'y3': ydata3, 'kwargs3': kwargs3}
+    extra_serie1 = {"tooltip": {"y_start": "", "y_end": " balls"}}
+
+    chartdata = {
+        'x': xdata,
+        'name1': 'series 1', 'y1': ydata1, 'kwargs1': kwargs1, 'extra1': extra_serie1,
+        'name2': 'series 2', 'y2': ydata2, 'kwargs2': kwargs2, 'extra2': extra_serie1,
+        'name3': 'series 3', 'y3': ydata3, 'kwargs3': kwargs3, 'extra3': extra_serie1
+    }
     charttype = "scatterChart"
     data = {
         'charttype': charttype,
         'chartdata': chartdata,
     }
-    return render_to_response('scatterchart.html', data)
\ No newline at end of file
+    return render_to_response('scatterchart.html', data)
